import { DocumentEditor, HighlightColor } from '../../document-editor/index';
import { L10n } from '@syncfusion/ej2-base';
import { HighlightColorInfo } from './ribbon-interfaces';
import { ItemModel } from '@syncfusion/ej2-splitbuttons';
/**
 * Helper class for font operations in Document Editor
 */
export declare class FontHelper {
    /**
     * Get highlight color items
     * @param {L10n} localObj - Localization object
     * @param {string} id - ID for the highlight color items
     * @returns {HighlightColorInfo[]} Array of highlight color items
     */
    static getHighlightColorItems(localObj: L10n, id: string): HighlightColorInfo[];
    /**
     * Get HighlightColor enum value based on the color string
     * @param {string} color - Color string in rgb format
     * @returns {HighlightColor} HighlightColor enum value
     */
    static getHighlightColor(color: string): HighlightColor;
    /**
     * Get background color from HighlightColor enum
     * @param {HighlightColor} highlightColor - HighlightColor enum value
     * @returns {string} Background color string in rgb format
     */
    static getBackgroundColorFromHighlightColor(highlightColor: HighlightColor): string;
    /**
     * Apply highlight color to selection
     * @param {DocumentEditor} documentEditor - Document editor instance
     * @param {string} color - Color string in rgb format
     * @returns {string} Applied highlight color
     */
    static applyHighlightColor(documentEditor: DocumentEditor, color: string): string;
    /**
     * Apply font formatting action
     * @param {DocumentEditor} documentEditor - Document editor instance
     * @param {string} action - Action to perform (bold, italic, etc.)
     * @returns {void}
     */
    static applyFontFormatting(documentEditor: DocumentEditor, action: string): void;
    /**
     * Apply case change to selection
     * @param {DocumentEditor} documentEditor - Document editor instance
     * @param {L10n} localObj  - Localization object
     * @param {string} caseType - Case type to apply
     * @returns {void}
     */
    static applyChangeCase(documentEditor: DocumentEditor, localObj: L10n, caseType: string): void;
    /**
     * Change font family
     * @param {DocumentEditor} documentEditor - Document editor instance
     * @param {string} fontFamily - Font family to apply
     * @returns {void}
     */
    static changeFontFamily(documentEditor: DocumentEditor, fontFamily: string): void;
    /**
     * Change font size
     * @param {DocumentEditor} documentEditor - Document editor instance
     * @param {string | number} fontSize - Font size to apply
     * @returns {void}
     */
    static changeFontSize(documentEditor: DocumentEditor, fontSize: string | number): void;
    /**
     * Change font color
     * @param {DocumentEditor} documentEditor - Document editor instance
     * @param {string} color - Color to apply
     * @returns {void}
     */
    static changeFontColor(documentEditor: DocumentEditor, color: string): void;
    /**
     * Update toggle button state
     * @param {HTMLElement} button - Button element
     * @param {boolean} isActive - Whether the button should be active
     * @returns {void}
     */
    static updateToggleButtonState(button: HTMLElement, isActive: boolean): void;
    /**
     * Get font size items
     * @returns {string[]} Array of font size items
     */
    static getFontSizeItems(): string[];
    /**
     * Get change case items
     * @param {L10n} localObj - Localization object
     * @param {string} commonId - Common ID for localization
     * @returns {ItemModel[]} Array of change case items
     */
    static getChangeCaseItems(localObj: L10n, commonId: string): ItemModel[];
    /**
     * Increase font size
     * @param {DocumentEditor} documentEditor - Document editor instance
     * @returns {void}
     */
    static increaseFontSize(documentEditor: DocumentEditor): void;
    /**
     * Decrease font size
     * @param {DocumentEditor} documentEditor - Document editor instance
     * @returns {void}
     */
    static decreaseFontSize(documentEditor: DocumentEditor): void;
}
